Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1078)

Unified Diff: chrome/browser/ui/cocoa/browser_window_layout.h

Issue 2489373002: [Mac] (More) RTL support for tab strip (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/browser_window_layout.h
diff --git a/chrome/browser/ui/cocoa/browser_window_layout.h b/chrome/browser/ui/cocoa/browser_window_layout.h
index d9b9396d20657bf8f060a8346e1a2f4ec6abd6e6..f500369053379b7409ed710f380b5d95f3c02879 100644
--- a/chrome/browser/ui/cocoa/browser_window_layout.h
+++ b/chrome/browser/ui/cocoa/browser_window_layout.h
@@ -85,10 +85,10 @@ struct LayoutParameters {
struct TabStripLayout {
// The frame of the tab strip in window coordinates.
NSRect frame;
- // The left indent for the controls of the TabStripController.
- CGFloat leftIndent;
- // The right indent for the controls of the TabStripController.
- CGFloat rightIndent;
+ // The leading indent for the controls of the TabStripController.
+ CGFloat leadingIndent;
+ // The trailing indent for the controls of the TabStripController.
+ CGFloat trailingIndent;
// Whether the TabStripController needs to add custom traffic light buttons.
BOOL addCustomWindowControls;
// The frame of the avatar in window coordinates.
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_controller_private.mm ('k') | chrome/browser/ui/cocoa/browser_window_layout.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698